User Guide
==========

.. note::
    This document is still incomplete, and will contain typos and mistakes in
    grammar due to my poor English skill. If you find any incorrect expression,
    please let me know at `issues <https://github.com/miyakogi/wdom/issues>`_ or
    send `PR <https://github.com/miyakogi/wdom/pulls>`_. Any small improvements
    or suggestions (e.g. just changing **a** to **the**) are welcome!

Contents
--------

.. toctree::
    :maxdepth: 2

    dom
    wdom
    load_resource
    new_features
    theming
    freezing
